@@ -14,7 +14,6 @@ if (!nzchar(Sys.getenv("RTUMBLR_TOKEN"))) {
 }
 
 vcr::vcr_configure(
-  filter_sensitive_data = list("<<<API TOKEN>>>" = get_rtumblr_token_from_envvar()$consumer_key),
+  filter_query_parameters = list("api_key" = ""),
   dir = vcr::vcr_test_path("fixtures")
 )
-vcr::check_cassette_names()
